mod api;
mod cli;
pub mod db;
mod error;
mod repo;

use clap::Parser;
pub use error::{Result, ServerError};
use repo::MetaRepoMgr;
use repo::RepoGroupManager;
use std::path::PathBuf;
use std::sync::Arc;
use tokio::sync::RwLock;

#[derive(Clone)]
pub struct Config {
    data_dir: PathBuf,
    api_key: String,
}

#[derive(Clone)]
pub struct Global {
    config: Config,
    repo_manager: Arc<RwLock<MetaRepoMgr>>,
    db: sea_orm::DbConn,
    pkg_filename_re: regex::Regex,
}

#[tokio::main]
async fn main() -> crate::Result<()> {
    let cli = cli::Cli::parse();
    cli.run().await
}
